summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/form.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/formeditor/form.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/formeditor/form.h')
-rw-r--r--kexi/formeditor/form.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/formeditor/form.h b/kexi/formeditor/form.h
index d41d7a29..7df731c6 100644
--- a/kexi/formeditor/form.h
+++ b/kexi/formeditor/form.h
@@ -169,21 +169,21 @@ class KFORMEDITOR_EXPORT Form : public TQObject
//! \return the form's toplevel widget, or 0 if designMode() == false.
TQWidget* widget() const;
// //! \return the FormManager tqparent of this form.
// FormManager* manager() const { return d->manager; }
/*! \return A pointer to the currently active Container, ie the tqparent Container for a simple widget,
and the widget's Container if it is itself a container.
*/
Container* activeContainer();
/*! \return A pointer to the tqparent Container of the currently selected widget.
It is the same as activeContainer() for a simple widget, but unlike this function
- it will also return the tqparent Container if the widget itself is a Container.
+ it will also return the parent Container if the widget itself is a Container.
*/
Container* parentContainer(TQWidget *w=0);
/*! \return The \ref Container which is a tqparent of all widgets in \a wlist.
Used by \ref activeContainer(), and to find where
to paste widgets when multiple widgets are selected. */
ObjectTreeItem* commonParentContainer(WidgetList *wlist);
@@ -289,7 +289,7 @@ class KFORMEDITOR_EXPORT Form : public TQObject
(called for example before saving or displaying the tab order dialog).
Automatically sorts widget from the top-left to bottom-right corner.
Widget can be grouped with containers. In paticular, for tab widgets,
- child widgets should ordered by tqparent tab's order. */
+ child widgets should ordered by parent tab's order. */
void autoAssignTabStops();
#ifdef KEXI_DEBUG_GUI
@@ -169,21 +169,21 @@ class KFORMEDITOR_EXPORT Form : public TQObject
//! \return the form's toplevel widget, or 0 if designMode() == false.
TQWidget* widget() const;
-// //! \return the FormManager tqparent of this form.
+// //! \return the FormManager parent of this form.
// FormManager* manager() const { return d->manager; }
@@ -169,21 +169,21 @@ class KFORMEDITOR_EXPORT Form : public TQObject
// FormManager* manager() const { return d->manager; }
- /*! \return A pointer to the currently active Container, ie the tqparent Container for a simple widget,
+ /*! \return A pointer to the currently active Container, ie the parent Container for a simple widget,
and the widget's Container if it is itself a container.
*/
@@ -169,21 +169,21 @@ class KFORMEDITOR_EXPORT Form : public TQObject
*/
Container* activeContainer();
- /*! \return A pointer to the tqparent Container of the currently selected widget.
+ /*! \return A pointer to the parent Container of the currently selected widget.
It is the same as activeContainer() for a simple widget, but unlike this function
@@ -169,21 +169,21 @@ class KFORMEDITOR_EXPORT Form : public TQObject
*/
Container* parentContainer(TQWidget *w=0);
- /*! \return The \ref Container which is a tqparent of all widgets in \a wlist.
+ /*! \return The \ref Container which is a parent of all widgets in \a wlist.
Used by \ref activeContainer(), and to find where
to paste widgets when multiple widgets are selected. */